@@ -176,7 +176,7 @@ settings_dialog_display (GtkWidget *parent, ConfManager *conf)
 	if (!settings_dialog) {
 		/* create the dialog */
 		settings_dialog = gtk_dialog_new_with_buttons (
-			_("Mergeant settings"), parent, 0,
+			_("Mergeant Preferences"), parent, 0,
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
 			NULL);
 		gtk_dialog_set_has_separator (GTK_DIALOG (settings_dialog), FALSE);
